// This program is a reproducer for two problems I observed when playing
// multiple videos with LibVLC 2.0.5* on Linux.
// (http://mailman.videolan.org/pipermail/vlc-devel/2013-January/091603.html)
//
// 1. Crash in FontConfig. Workaround: delete/rename libfreetype_plugin.so
// 2. ALSA error messages. Workaround: use PulseAudio ;-)
//
// Usage:
//   gcc -o mplay mplay.c -lvlc
//   ./mplay

#include <unistd.h>
#include <stdlib.h>
#include <vlc/libvlc.h>
#include <vlc/libvlc_media.h>
#include <vlc/libvlc_media_player.h>

libvlc_instance_t * vlc = NULL;
const int width = 352, height = 288;

void play(const char *name);

int main(int argc, const char *argv[])
{
    argv++; argc--;
    vlc = libvlc_new(argc, argv);

    const char * num = getenv("NUM");
    int i, n = (num ? atoi(num) : 4);
    for (i = 0; i < n; i++)
    {
        // From http://cslr.co.uk/video/EngineerTB02.mpg
        // but any other video should do 
        play("EngineerTB02.mpg");
    }
    sleep(10);
    return 0;
}

void * lockFrame(void *obj, void **plane)
{
    posix_memalign(plane, 32, width*height*4);
    return *plane;
}

void displayFrame(void *obj, void *picture)
{
    free(picture);
}

void play(const char *name)
{
    libvlc_media_t * m = libvlc_media_new_path(vlc, name);
    libvlc_media_player_t * mp = libvlc_media_player_new_from_media(m);
    libvlc_media_release(m);
    libvlc_video_set_format(mp, "RV32", width, height, width*4);
    libvlc_video_set_callbacks(mp, lockFrame, NULL, displayFrame, NULL);
    libvlc_media_player_play(mp);
}
